EVec

Struct EVec 

pub struct EVec<T> { /* private fields */ }
A vector that is guaranteed to be empty.

Naturally, the following operations are impossible with EVec:

  • append
  • insert
  • push
  • remove

And many others have been elided for being pointless (like drain and sort).

Implementations

Source

impl<T> EVec<T>

pub const fn contains(&self, _: &T) -> bool

Go ahead, see if it’s in there.

pub fn from_vec(vec: Vec<T>) -> Option<EVec<T>>

Attempt to convert a possibly non-empty Vec into one that is guaranteed to be empty.

pub const fn is_empty(&self) -> bool

This may be the best function I’ve ever written. Go on, guess the return value.

pub fn iter(&self) -> Empty<&T>

Wow, it’s even an Iterator?

pub const fn len(&self) -> usize

No, sorry, this is the best function I’ve ever written.

pub fn new() -> EVec<T>

Think of the possibilities!